@@ -11,6 +11,9 @@ use File::Copy qw/move/;
 # needed
 use Template;
 use EBook::EPUB;
+use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
+use File::Copy;
+use File::Spec;
 
 # ours
 use PDF::Imposition;
@@ -210,7 +213,9 @@ sub purged_extensions {
     my $self = shift;
     my @exts = (qw/.pdf .a4.pdf .lt.pdf
                    .tex .log .aux .toc .ok
-                   .html .bare.html .epub/);
+                   .html .bare.html .epub
+                   .zip
+                  /);
     return @exts;
 }
 
@@ -221,7 +226,7 @@ sub purge {
         die "wtf?" if ($ext eq '.muse');
         my $target = $basename . $ext;
         if (-f $target) {
-            # warn "Removing $target\n";
+            warn "Removing $target\n";
             unlink $target or die "Couldn't unlink $target $!";
         }
     }
@@ -303,6 +308,13 @@ the imposed output.
 
 =item a4_pdf
 
+=item zip
+
+The zipped sources. Beware that if you don't call html or tex before
+this, the attachments (if any) are ignored if both html and tex files
+exist. Hence, the muse-compile.pl scripts forces the --tex and --html
+switches.
+
 =back
 
 =cut
@@ -310,27 +322,29 @@ the imposed output.
 sub html {
     my $self = shift;
     $self->purge('.html');
+    my $outfile = $self->name . '.html';
     $self->tt->process($self->templates->html,
                        {
                         doc => $self->document,
                         css => ${ $self->templates->css },
                         options => $self->options,
                        },
-                       $self->name . '.html',
+                       $outfile,
                        { binmode => ':encoding(utf-8)' })
       or die $self->tt->error;
-
+    return $outfile;
 }
 
 sub bare_html {
     my $self = shift;
     $self->purge('.bare.html');
+    my $outfile = $self->name . '.bare.html';
     $self->tt->process($self->templates->bare_html,
                        {
                         doc => $self->document,
                         options => $self->options,
                        },
-                       $self->name . '.bare.html',
+                       $outfile,
                        { binmode => ':encoding(utf-8)' })
       or die $self->tt->error;
 }
@@ -352,8 +366,8 @@ sub _compile_imposed {
     # impose, then rename.
     $self->tex(papersize => "half-$size");
     my $pdf = $self->pdf;
+    my $outfile = $self->name . ".$size.pdf";
     if ($pdf) {
-        my $outfile = $self->name . ".$size.pdf";
         my $imposer = PDF::Imposition->new(
                                            file => $pdf,
                                            schema => '2up',
@@ -366,11 +380,13 @@ sub _compile_imposed {
     else {
         die "PDF was not produced!";
     }
+    return $outfile;
 }
 
 
 sub tex {
     my ($self, @args) = @_;
+    my $texfile = $self->name . '.tex';
     die "Wrong usage" if @args % 2;
     my %arguments = @args;
 
@@ -397,9 +413,10 @@ sub tex {
                         doc => $self->document,
                         options => { %params },
                        },
-                       $self->name . '.tex',
+                       $texfile,
                        { binmode => ':encoding(utf-8)' })
       or die $self->tt->error;
+    return $texfile;
 }
 
 sub pdf {
@@ -456,11 +473,40 @@ sub pdf {
     return $output;
 }
 
+sub zip {
+    my $self = shift;
+    $self->purge('.zip');
+    my $zipname = $self->name . '.zip';
+    my $tempdir = File::Temp->newdir;
+    my $tempdirname = $tempdir->dirname;
+    foreach my $todo (qw/tex html/) {
+        my $target = $self->name . '.' . $todo;
+        unless (-f $target) {
+            $self->$todo;
+        }
+        die "Couldn't produce $target" unless -f $target;
+        copy($target, $tempdirname)
+          or die "Couldn't copy $target in $tempdirname $!";
+    }
+    copy ($self->name . '.muse', $tempdirname);
+
+    my $text = $self->document;
+    foreach my $attach ($text->attachments) {
+        copy($attach, $tempdirname) or die $!;
+    }
+    my $zip = Archive::Zip->new;
+    $zip->addTree($tempdirname, $self->name) == AZ_OK
+      or die "Failure zipping $tempdirname";
+    $zip->writeToFileNamed($zipname) == AZ_OK
+      or die "Failure writing $zipname";
+    return $zipname;
+}
+
+
 sub epub {
     my $self = shift;
     $self->purge('.epub');
     my $epubname = $self->name . '.epub';
-    unlink $epubname if -f $epubname;
 
     my $text = $self->document;
 
@@ -595,6 +641,7 @@ sub epub {
 
     # finish
     $epub->pack_zip($epubname);
+    return $epubname;
 }
 
 sub _remove_tags {
